import React from 'react';
import type { DivAttributes } from '../_utils/types';
import type { AvatarIconProps, AvatarLabelProps, AvatarPortraitProps, AvatarProps, AvatarRef, AvatarRoles, AvatarRoleType, BaseAvatarProps } from './Avatar.types';
declare function AvatarInner({ as, clickable, disabled, href, size, children, onBlur, onFocus, rel, role, target, ...props }: AvatarProps<AvatarRoleType>, ref: AvatarRef<AvatarRoleType>): React.JSX.Element;
export declare const Icon: React.ForwardRefExoticComponent<DivAttributes & AvatarIconProps & React.RefAttributes<HTMLDivElement>>;
export declare const Label: React.ForwardRefExoticComponent<DivAttributes & AvatarLabelProps & React.RefAttributes<HTMLDivElement>>;
export declare const Portrait: React.ForwardRefExoticComponent<DivAttributes & AvatarPortraitProps & React.RefAttributes<HTMLDivElement>>;
/**

 We use avatars to visually represent our users, places, and things in the app.
 These can be in the form of rich media or representative illustrations.

 @since 10.19.0

 @see [Storybook](https://stories.core.procore.com/?path=/story/core-react_demos-avatar--demo)

 @see [Design Guidelines](https://design.procore.com/avatar)

 @a11y Avatar's need a `aria-label` and can be enhanced with `role` for interaction. If decorative only, add `aria-hidden`. The inaccessible `clickable` prop is for UI only

 */
export declare const NextAvatar: (<Role extends AvatarRoles>(props: AvatarProps<Role>) => ReturnType<typeof AvatarInner>) & {
    Icon: React.ForwardRefExoticComponent<DivAttributes & AvatarIconProps & React.RefAttributes<HTMLDivElement>>;
    Label: React.ForwardRefExoticComponent<DivAttributes & AvatarLabelProps & React.RefAttributes<HTMLDivElement>>;
    Portrait: React.ForwardRefExoticComponent<DivAttributes & AvatarPortraitProps & React.RefAttributes<HTMLDivElement>>;
};
/**

 We use avatars to visually represent our users, places, and things in the app.
 These can be in the form of rich media or representative illustrations.

 @since 10.19.0

 @see [Storybook](https://stories.core.procore.com/?path=/story/core-react_demos-avatar--demo)

 @see [Design Guidelines](https://design.procore.com/avatar)

 @a11y Avatar's need a `aria-label` and can be enhanced with `role` for interaction. If decorative only, add `aria-hidden`. The inaccessible `clickable` prop is for UI only

 */
export declare const Avatar: (<Role extends AvatarRoles>(props: AvatarProps<Role> | (BaseAvatarProps & {
    ref?: React.ComponentPropsWithRef<'div'>['ref'];
})) => ReturnType<typeof AvatarInner>) & {
    Icon: React.ForwardRefExoticComponent<DivAttributes & AvatarIconProps & React.RefAttributes<HTMLDivElement>>;
    Label: React.ForwardRefExoticComponent<DivAttributes & AvatarLabelProps & React.RefAttributes<HTMLDivElement>>;
    Portrait: React.ForwardRefExoticComponent<DivAttributes & AvatarPortraitProps & React.RefAttributes<HTMLDivElement>>;
};
export {};
