import React from 'react';
import type { PageComponentProps, PageFooterProps } from '../PageLayout/PageLayout.types';
import type { Props } from '../_utils/types';
import type { DetailPageCardProps, DetailPageProps, DetailPageWidth } from './DetailPage.types';
export declare const DetailPageViewContext: React.Context<{
    width: DetailPageWidth;
    hasNavigation: boolean;
}>;
export declare const Heading: React.ForwardRefExoticComponent<Props & React.RefAttributes<HTMLDivElement>>;
export declare const Body: React.ForwardRefExoticComponent<PageComponentProps & React.RefAttributes<HTMLDivElement>>;
export declare const Footer: React.ForwardRefExoticComponent<PageFooterProps & React.RefAttributes<HTMLDivElement>>;
export declare const FooterNotation: React.ForwardRefExoticComponent<Props & React.RefAttributes<HTMLDivElement>>;
export declare const FooterActions: React.ForwardRefExoticComponent<Props & React.RefAttributes<HTMLDivElement>>;
export declare const Card: React.ForwardRefExoticComponent<DetailPageCardProps & React.RefAttributes<HTMLDivElement>>;
/**

 A detail page is used when an object is selected from a list page. The layout
 can adhere to varying predefined widths depending on use case.

  - DetailPage
    - DetailPage.Main
      - DetailPage.Header
        - DetailPage.Breadcrumbs
          - Breadcrumbs
        - DetailPage.Banner
          - Banner
        - DetailPage.Title
          - Title or H1
        - DetailPage.Tabs
          - Tabs
      - DetailPage.Body
        - DetailPage.Title
        - DetailPage.Banner
        - DetailPage.Card
          - DetailPage.Banner
          - DetailPage.Section
            - DetailPage.Section
          - DetailPage.Section
      - DetailPage.Footer
        - DetailPage.FooterNotation
        - DetailPage.FooterActions
          - Button
    - DetailPage.Aside
      - Panel

 @since 10.19.0

 @see [Storybook](https://stories.core.procore.com/?path=/story/core-react_demos-detailpage--edit)

 @see [Design Guidelines](https://design.procore.com/detail)

 */
export declare const DetailPage: React.ForwardRefExoticComponent<DetailPageProps & React.RefAttributes<HTMLDivElement>> & {
    Main: React.ForwardRefExoticComponent<import("../PageLayout/PageLayout.types").PageMainProps & React.RefAttributes<HTMLDivElement>>;
    Header: React.ForwardRefExoticComponent<import("../PageLayout/PageLayout.types").PageHeaderProps & React.RefAttributes<HTMLDivElement>>;
    Breadcrumbs: React.ForwardRefExoticComponent<Props & React.RefAttributes<HTMLDivElement>>;
    Card: React.ForwardRefExoticComponent<DetailPageCardProps & React.RefAttributes<HTMLDivElement>>;
    Banner: React.ForwardRefExoticComponent<Props & React.RefAttributes<HTMLDivElement>>;
    Title: React.ForwardRefExoticComponent<Props & React.RefAttributes<HTMLDivElement>>;
    Heading: React.ForwardRefExoticComponent<Props & React.RefAttributes<HTMLDivElement>>;
    Tabs: React.ForwardRefExoticComponent<Props & React.RefAttributes<HTMLDivElement>>;
    Footer: React.ForwardRefExoticComponent<PageFooterProps & React.RefAttributes<HTMLDivElement>>;
    FooterActions: React.ForwardRefExoticComponent<Props & React.RefAttributes<HTMLDivElement>>;
    FooterNotation: React.ForwardRefExoticComponent<Props & React.RefAttributes<HTMLDivElement>>;
    Section: React.ForwardRefExoticComponent<import("../Section").SectionProps & React.RefAttributes<HTMLDivElement>>;
    Body: React.ForwardRefExoticComponent<PageComponentProps & React.RefAttributes<HTMLDivElement>>;
    Aside: React.ForwardRefExoticComponent<import("../PageLayout/PageLayout.types").PageAsideProps & React.RefAttributes<HTMLDivElement>>;
};
