import React from 'react';
import { Heading } from '../Section/Section';
import type { TypographyProps } from '../Typography/Typography.types';
import type { RenderProps } from '../_hooks/Visibility';
import type { DivAttributes, SpanAttributes } from '../_utils/types';
import type { ConfirmModalProps, ModalBodyProps, ModalCloseableHeaderProps, ModalContainerProps, ModalProps } from './Modal.types';
export declare const ConfirmModal: React.ForwardRefExoticComponent<ConfirmModalProps & React.RefAttributes<HTMLDivElement>>;
declare function ModalState(props: RenderProps): React.JSX.Element;
/**

 We use modals to present additional actions, information, or forms on pages
 where a user’s experience would benefit from remaining on the same page.
 They can include graphics, inputs, buttons, and other elements as needed to
 produce the workflow or action needed.

 Do not include modals on pages with complicated UI layouts.

 @since 10.19.0

 @see [Storybook](https://stories.core.procore.com/?path=/story/core-react_demos-modal--demo)

 @see [Design Guidelines](https://design.procore.com/modal)

 */
export declare const Modal: React.ForwardRefExoticComponent<ModalProps & React.RefAttributes<HTMLDivElement>> & {
    Body: React.ForwardRefExoticComponent<ModalBodyProps & React.RefAttributes<HTMLDivElement>>;
    Container: React.ForwardRefExoticComponent<ModalContainerProps & React.RefAttributes<HTMLDivElement>>;
    Content: import("styled-components").StyledComponent<"div", any, {
        $compact?: boolean | undefined;
    }, never>;
    Footer: import("styled-components").StyledComponent<"div", any, {}, never>;
    FooterButtons: React.ForwardRefExoticComponent<ModalCloseableHeaderProps & React.RefAttributes<HTMLDivElement>>;
    FooterNotation: React.ForwardRefExoticComponent<SpanAttributes & TypographyProps & React.RefAttributes<HTMLSpanElement>>;
    FooterSummary: React.ForwardRefExoticComponent<DivAttributes & React.RefAttributes<HTMLDivElement>>;
    Header: React.ForwardRefExoticComponent<ModalCloseableHeaderProps & React.RefAttributes<HTMLDivElement>>;
    Heading: typeof Heading;
    Overlay: import("styled-components").StyledComponent<"div", any, {}, never>;
    Scrim: import("styled-components").StyledComponent<"div", any, {}, never>;
    State: typeof ModalState;
    Section: React.ForwardRefExoticComponent<import("../Section").SectionProps & React.RefAttributes<HTMLDivElement>>;
};
export {};
