import React from 'react';
import type { Props } from '../_utils/types';
import type { HeroMediaProps, HeroTextProps, InteractableTileProps, LinkTileProps, Roles, TileProps, TileRef } from './NextTile.types';
export declare const InteractableTile: React.ForwardRefExoticComponent<Omit<InteractableTileProps, "role"> & React.RefAttributes<HTMLDivElement>>;
export declare const LinkTile: React.ForwardRefExoticComponent<Omit<LinkTileProps, "role"> & React.RefAttributes<HTMLAnchorElement>>;
declare function TileInner<Role extends Roles = 'none'>({ role, ...props }: TileProps<Role>, ref: TileRef<Role>): React.JSX.Element | null;
/**
 * <NextTile role={checkbox}/> can be used as single checkbox as well as in group.
 *
 * Single
 * ```
 * <NextTile role={checkbox} value="ThomasAnderson" onChange=((value) => console.log(value) />
 * <NextTile role={checkbox} value="WhiteRabbit" onChange=((value) => console.log(value) />
 * ```
 *
 * Group
 * ```
 * <CheckboxGroup label="Matrix" onChange=((value) => console.log(value)>
 *    <NextTile role={checkbox} value="ThomasAnderson"/>
 *    <NextTile role={checkbox} value="WhiteRabbit"/>
 * </CheckboxGroup>
 * ```
 *
 * @since 11.6.0
 */
export declare const NextTile: (<Role extends Roles = "none">(props: TileProps<Role> & {
    ref?: TileRef<Role> | undefined;
}) => ReturnType<typeof TileInner>) & {
    Actions: React.ForwardRefExoticComponent<Props & React.RefAttributes<HTMLDivElement>>;
    Content: React.ForwardRefExoticComponent<HeroTextProps & React.RefAttributes<HTMLDivElement>>;
    Footer: React.ForwardRefExoticComponent<Props & React.RefAttributes<HTMLDivElement>>;
    HeroText: React.ForwardRefExoticComponent<HeroTextProps & React.RefAttributes<HTMLDivElement>>;
    HeroMedia: React.ForwardRefExoticComponent<HeroMediaProps & React.RefAttributes<HTMLDivElement>>;
};
export {};
