import type { ReactNode } from 'react';
/**
 * All the possible zones in a page header template.
 * @since 12.20.0
 */
export declare type PageHeaderTemplateProps = {
    /** A zone for buttons, dropdowns, etc. When there are multiple actions,
     * start with a `React.Fragment` to enable better responsiveness.
     *
     * **This zone may change location** based on what other props are
     * supplied, screen size, heading length, etc.
     * @example actions={<><Button>1</Button><Button>2</Button></>}
     */
    actions?: ReactNode;
    /** A zone to place a page level top banner. This is the second highest
     * banner level possible, only the global banner from the global header
     * could be above it.
     */
    banner?: ReactNode;
    /**
     * A generic zone that goes in front of the heading. Used for images and icons.
     */
    beforeTitleZone?: ReactNode;
    /** A zone for `Breadcrumbs`. */
    breadcrumbs?: ReactNode;
    /**
     * An extra zone for piloting designs. A 'replace me' if necessary zone.
     */
    /**
     * Heading for the page. The H1 is handled for you.
     */
    heading?: string;
    /** A zone for pills. When multiple pills, start with a `React.Fragment`
     * @example pills={<><Pill>1</Pill><Pill>2</Pill></>}
     */
    pills?: ReactNode;
    /** Text beneath the h1 heading. */
    subheading?: string;
    /** A zone for `Tabs`. */
    tabs?: ReactNode;
    /** A zone for a `ToggleAction` that manages a page level panel. */
    toggleAction?: ReactNode;
};
