import React from 'react';
import type { TypographyProps } from '../Typography';
import type { DivAttributes } from '../_utils/types';
import type { PanelBodyProps, PanelHeaderActionProps, PanelHeaderProps, PanelProps, PanelQaTags, PanelTitleTooltipProps } from './Panel.types';
export declare const MoreIcon: React.FC<DivAttributes & {
    qa?: Pick<PanelQaTags, 'moreIcon'>;
}>;
export declare const TitleTooltip: React.FC<PanelTitleTooltipProps>;
/**

 Panels help users complete tasks or view additional information alongside the
 main content of a page.

 Panels are often initiated by clicking on an item somewhere on the main page,
 and they often contain additional information or options specific to that item.

 @since 10.19.0

 @see [Storybook](https://stories.core.procore.com/?path=/story/core-react_demos-panel--demo)

 @see [Design Guidelines](https://design.procore.com/panel)

 */
export declare const Panel: React.ForwardRefExoticComponent<PanelProps & React.RefAttributes<HTMLDivElement>> & {
    Body: React.ForwardRefExoticComponent<PanelBodyProps & React.RefAttributes<HTMLDivElement>>;
    Footer: React.ForwardRefExoticComponent<DivAttributes & React.RefAttributes<HTMLDivElement>>;
    FooterActions: React.ForwardRefExoticComponent<DivAttributes & React.RefAttributes<HTMLDivElement>>;
    FooterNotation: React.ForwardRefExoticComponent<DivAttributes & React.RefAttributes<HTMLDivElement>>;
    Header: React.ForwardRefExoticComponent<PanelHeaderProps & React.RefAttributes<HTMLDivElement>>;
    HeaderAction: React.ForwardRefExoticComponent<PanelHeaderActionProps & React.RefAttributes<HTMLSpanElement>>;
    HeaderActions: React.ForwardRefExoticComponent<DivAttributes & {
        qa?: Pick<PanelQaTags, "moreIcon"> | undefined;
    } & React.RefAttributes<HTMLDivElement>>;
    Section: React.ForwardRefExoticComponent<import("../Section").SectionProps & React.RefAttributes<HTMLDivElement>>;
    Title: React.ForwardRefExoticComponent<TypographyProps & {
        qa?: Pick<PanelQaTags, "title"> | undefined;
        id?: string | undefined;
    } & React.RefAttributes<HTMLSpanElement>>;
};
