import type React from 'react';
import type { Props } from '../_utils/types';
export interface SectionProviderProps {
    /**
     * @since 10.19.0
     */
    children: React.ReactNode;
}
export interface SectionProps extends Props {
    /**
     * @description Actions of Buttons and Dropdowns to render. If a function,
     * the open state is provided as `open` key
     * @since 10.19.0
     */
    actions?: React.ReactNode | ((section: {
        open: boolean;
    }) => React.ReactNode);
    /**
     * @since 12.9.0
     */
    banner?: React.ReactNode;
    /**
     * @description Enable the expand and collapse accordion feature.
     *  Requires a unique ID across sections, unique within the provider (DetailPage.Card) and
     *  requires a heading on the section. Closed sections will not render its children.
     * @since 10.19.0
     */
    expandId?: string | number;
    /**
     * @description Heading text for the section
     * @since 10.19.0
     */
    heading?: string;
    /**
     * @description If expandable, start open or closed
     * @since 10.19.0
     */
    initialIsOpen?: boolean;
    /**
     * @description Title assets
     * @since 10.19.0
     */
    assets?: React.ReactNode;
    /**
     * @description Title pills
     * @since 10.19.0
     */
    pills?: React.ReactNode;
    /**
     * @description Title subtext
     * @since 10.19.0
     */
    subtext?: React.ReactNode;
}
export interface SectionContextAPI {
    /**
     * @since 10.19.0
     */
    open: {
        [id: string]: boolean;
    };
    /**
     * @since 10.19.0
     */
    setSection: (id: string | number, open: boolean) => void;
    /**
     * @since 10.19.0
     */
    toggleSection: (id: string | number) => void;
}
