import React from 'react';
import type { SettingsPageFooterProps, SettingsPageProps } from './SettingsPage.types';
export declare const Footer: React.ForwardRefExoticComponent<SettingsPageFooterProps & React.RefAttributes<HTMLDivElement>>;
/**

 A settings page is basically a copy of DetailPage. However, it may have some differences in a future.

  - SettingsPage
    - SettingsPage.Main
      - SettingsPage.Header
        - SettingsPage.Breadcrumbs
          - Breadcrumbs
        - SettingsPage.Banner
          - Banner
        - SettingsPage.Title
          - Title or H1
        - SettingsPage.Tabs
          - Tabs
      - SettingsPage.Body
        - SettingsPage.Title
        - SettingsPage.Banner
        - SettingsPage.Card
          - SettingsPage.Banner
          - SettingsPage.Section
            - SettingsPage.Section
          - SettingsPage.Section
      - SettingsPage.Footer or Form.SettingsPageFooter
        - SettingsPage.FooterNotation
        - SettingsPage.FooterActions
          - Button
      - Panel

 @since TBD

 @see [Storybook](https://stories.core.procore.com/?path=/story/core-react_demos-detailpage--edit)

 @see [Design Guidelines](https://design.procore.com/detail)

 */
export declare const SettingsPage: React.ForwardRefExoticComponent<SettingsPageProps & React.RefAttributes<HTMLDivElement>> & {
    Main: React.ForwardRefExoticComponent<import("../PageLayout/PageLayout.types").PageMainProps & React.RefAttributes<HTMLDivElement>>;
    Header: React.ForwardRefExoticComponent<import("..").PageHeaderProps & React.RefAttributes<HTMLDivElement>>;
    Breadcrumbs: React.ForwardRefExoticComponent<import("../_utils/types").Props & React.RefAttributes<HTMLDivElement>>;
    Card: React.ForwardRefExoticComponent<import("../DetailPage/DetailPage.types").DetailPageCardProps & React.RefAttributes<HTMLDivElement>>;
    Banner: React.ForwardRefExoticComponent<import("../_utils/types").Props & React.RefAttributes<HTMLDivElement>>;
    Title: React.ForwardRefExoticComponent<import("../_utils/types").Props & React.RefAttributes<HTMLDivElement>>;
    Heading: React.ForwardRefExoticComponent<import("../_utils/types").Props & React.RefAttributes<HTMLDivElement>>;
    Tabs: React.ForwardRefExoticComponent<import("../_utils/types").Props & React.RefAttributes<HTMLDivElement>>;
    Footer: React.ForwardRefExoticComponent<SettingsPageFooterProps & React.RefAttributes<HTMLDivElement>>;
    FooterActions: React.ForwardRefExoticComponent<import("../_utils/types").Props & React.RefAttributes<HTMLDivElement>>;
    FooterNotation: React.ForwardRefExoticComponent<import("../_utils/types").Props & React.RefAttributes<HTMLDivElement>>;
    Section: React.ForwardRefExoticComponent<import("../Section").SectionProps & React.RefAttributes<HTMLDivElement>>;
    Body: React.ForwardRefExoticComponent<import("..").PageProps & React.RefAttributes<HTMLDivElement>>;
};
