import type { Color } from '../_styles/colors';
import type { Props } from '../_utils/types';
export declare type SpinnerSize = 'xs' | 'sm' | 'md' | 'lg';
export declare type SpinnerVariant = 'light' | 'default' | 'button' | 'focus';
export interface SpinnerProps extends Props {
    /**
     * Spinner color, one of the
     * [HSL Palette](/web/style/colors/#hsl-palette) css strings
     * @since 10.19.0
     * @deprecated Use `variant` instead
     * @deprecatedSince 12.18.0
     */
    color?: Color;
    /**
     * The spinner label, only displayed when used as an overlay.
     * Label is not shown on `xs` and `sm` sizes.
     * Spinner should have `children`, otherwise the label will not be shown.
     * @since 10.19.0
     */
    label?: string;
    /**
     * The spinner will show if loading is true
     * @since 10.19.0
     */
    loading?: boolean;
    /**
     * The size of the spinner
     * @since 10.19.0
     */
    size?: SpinnerSize;
    /**
     * @since 10.19.0
     */
    variant?: SpinnerVariant;
    /**
     * Spinner option to be centered.
     * Use this prop if you need to center the spinner regardless of the height of its children.
     * @since 11.3.0
     */
    centered?: boolean;
}
