import type React from 'react';
import type { AnchorAttributes, DivAttributes, Props } from '../_utils/types';
export interface HeroTextProps extends Props {
}
export interface HeroMediaProps extends Props {
    overlay?: boolean;
    onOverlayClick?: React.MouseEventHandler<HTMLDivElement>;
}
export interface TileCommonProps extends Props {
    /**
     * @since 10.19.0
     */
    orientation: 'portrait' | 'landscape';
}
export interface InteractableTileProps extends TileCommonProps, DivAttributes {
    /**
     * To change tile behaviour
     * @since 10.19.0
     */
    variant?: 'interactive';
}
export interface LinkTileProps extends TileCommonProps, AnchorAttributes {
    /**
     * To change tile behaviour
     * @since 10.19.0
     */
    variant?: 'link';
}
export interface SelectableTileProps extends TileCommonProps, Omit<DivAttributes, 'onClick'> {
    /**
     * To change tile behaviour
     * @since 10.19.0
     */
    variant?: 'selectable';
    /**
     * A function for controlling `selected` Tile prop.
     * @since 10.19.0
     */
    onClick?: () => {};
    /**
     * Only with selectable variant.
     * @default false
     * @since 10.19.0
     */
    selected?: boolean;
    /**
     * Only with selectable variant.
     * @default false
     * @since 10.19.0
     */
    disabled?: boolean;
}
export declare type TileProps = SelectableTileProps | InteractableTileProps | LinkTileProps;
