import type { LinkButtonProps } from '../Button';
import type { PageHeaderTemplateProps } from '../PageTemplate/PageHeaderTemplate';
import type { PageTemplateProps } from '../PageTemplate/PageTemplate';
import type { UsingProps } from '../_utils/types';
export declare type ToolLandingPageHeaderTemplateProps = UsingProps<PageHeaderTemplateProps, 'heading', 'banner' | 'actions' | 'pills' | 'subheading' | 'tabs'> & {
    /**
     * Link for the settings page. Supports a component for the link,
     * like a link component for client side routing. Also supports
     * a string for a simple full-load href.
     *
     * @example Pass the component `settingsLink={RoutedLink}`
     *
     * Define the component example 1
  ```jsx
  const RoutedLink = React.forwardRef<HTMLAnchorElement>(function RoutedLink(
    props: LinkButtonProps,
    ref
  ) {
    return (
      <a {...props} href="/settings" ref={ref}>
        {props.children}
      </a>
    )
  })
  ```
  Define a component example 2
  ```jsx
  import { Link } from "react-router";
  
  function RoutedLink(props) {
    return (
      <Link
        {...props}
        to={{
          pathname: "/configure",
        }}
      />
    )
  }
  ```
     * @since 12.20.0
     */
    settingsLink?: string | LinkButtonProps['as'];
};
export declare type ToolLandingPageTemplateProps = Pick<PageTemplateProps, 'header' | 'pane' | 'children'> & {
    headerProps?: ToolLandingPageHeaderTemplateProps;
};
