/// <reference types="react" />
import type { Color } from '../_styles/colors';
import type { Props } from '../_utils/types';
export declare type Intent = 'h1' | 'h2' | 'h3' | 'body' | 'small' | 'label';
export declare type Weight = 'regular' | 'semibold' | 'bold';
export interface TypographyProps extends Props {
    /**
     * When children are a string or multiple elements, they will be wrapped
     * by a `span`. When it is a single element, classnames will
     * be added to it instead
     * @since 10.19.0
     * */
    children: React.ReactNode;
    /**
     * Change the HTML tag. This
     * [prop is from styled-components](https://styled-components.com/docs/api#as-polymorphic-prop)
     * __Warning__: If using TypeScript, it will not switch types and
     * some props may error. You can add `@ts-expect-error`.
     * See [styled-components issue](https://github.com/DefinitelyTyped/DefinitelyTyped/issues/30117)
     * @default 'span'
     * @since 10.19.0
     */
    as?: string | React.ComponentType<any>;
    /**
     * Changes font color, can be any of the `colors` object HSL Palette
     * @default 'gray15'
     * @since 10.19.0
     */
    color?: Color;
    /**
     * Changes the size of the font
     * @since 10.19.0
     */
    intent?: Intent;
    /**
     * Applies `font-style: italic` if enabled
     * @since 10.19.0
     */
    italic?: boolean;
    /**
     * Changes font weight if it is supported in the design system
     * @since 10.19.0
     */
    weight?: Weight;
    /**
     * Enables word wrapping and breaking within the component
     * @since 12.0.0
     */
    breakWord?: boolean;
}
