import type React from 'react';
export interface ReactElementWithRef<T extends any = any> extends React.ReactElement<T> {
    ref?: React.Ref<T>;
}
export declare type Size = 'auto' | 'block' | 'inherit' | 'lg' | 'md' | 'none' | 'sm' | 'xl' | 'xs' | 'xxl';
export declare type Placement = 'bottom' | 'bottom-left' | 'bottom-right' | 'center' | 'left' | 'left-bottom' | 'left-top' | 'right' | 'right-bottom' | 'right-top' | 'top' | 'top-left' | 'top-right';
export interface RenderProp<T> {
    children: React.ReactNode | ((props: T) => React.ReactNode);
}
export interface Props {
    children?: React.ReactNode;
    /**
     * Additional classNames
     */
    className?: string;
    /**
     * Additional CSS styles
     */
    style?: React.CSSProperties;
}
export declare type AnchorAttributes = React.AnchorHTMLAttributes<HTMLAnchorElement>;
export declare type ButtonAttributes = React.ButtonHTMLAttributes<HTMLButtonElement>;
export declare type DivAttributes = React.HTMLAttributes<HTMLDivElement>;
export declare type HeadingAttributes = React.HTMLAttributes<HTMLHeadingElement>;
export declare type InputAttributes = React.InputHTMLAttributes<HTMLInputElement>;
export declare type LabelAttributes = React.HTMLAttributes<HTMLLabelElement>;
export declare type LiAttributes = React.LiHTMLAttributes<HTMLLIElement>;
export declare type NavAttributes = DivAttributes;
export declare type OlAttributes = React.OlHTMLAttributes<HTMLOListElement>;
export declare type SpanAttributes = React.HTMLAttributes<HTMLSpanElement>;
export declare type SVGAttributes = React.SVGAttributes<SVGElement>;
export declare type TableAttributes = React.TableHTMLAttributes<HTMLTableElement>;
export declare type TbodyAttributes = DivAttributes;
export declare type TdAttributes = React.TdHTMLAttributes<HTMLTableCellElement>;
export declare type TheadAttributes = DivAttributes;
export declare type TextAreaAttributes = React.TextareaHTMLAttributes<HTMLTextAreaElement>;
export declare type ThAttributes = React.ThHTMLAttributes<HTMLTableHeaderCellElement>;
export declare type TrAttributes = DivAttributes;
export declare type UlAttributes = DivAttributes;
export declare type ImgAttributes = React.ImgHTMLAttributes<HTMLImageElement>;
export declare type AriaLabelled<P = never> = ({
    'aria-label': string;
} & P) | ({
    'aria-labelledby': string;
} & P);
/**
 * Helper to create a type with required and optional keys.
 */
export declare type UsingProps<
/** All possible props */
Props, 
/** Keys that will be required */
Always extends keyof Props, 
/** Other keys that will be supported */
Optional extends keyof Props = never> = Required<Pick<Props, Always>> & Partial<Pick<Props, Optional>>;
